OC.L10N.register(
    "news",
    {
    "Unread articles" : "Μη αναγνωσμένα άρθρα",
    "News" : "Νέα",
    "Shared with me" : "Διαμοιρασμένα με εμένα",
    "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
    "Download" : "Λήψη",
    "Close" : "Κλείσιμο",
    "Web address" : "Διεύθυνση ιστοσελίδας",
    "No folder" : "Κανένας φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Feed exists already!" : "Η ροή υπάρχει ήδη!",
    "New folder" : "Νέος φάκελος",
    "Folder exists already!" : "Ο φάκελος υπάρχει ήδη!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Τα διαπιστευτήρια Βασικής Πιστοποίησης HTTP πρέπει να αποθηκεύονται χωρίς κρυπτογράφηση! Όλοι με πρόσβαση στον διακομιστή ή τη βάση δεδομένων θα έχουν πρόσβαση σε αυτά!",
    "Credentials" : "Πιστοποιητικά",
    "Subscribe" : "Εγγραφή",
    "Last job ran {relativeTime}." : "Η τελευταία εργασία εκτελέστηκε {relativeTime}.",
    "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
    "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
    "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
    "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
    "Update interval" : "Εσωτερική ενημέρωση",
    "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
    "How many redirects the feed fetcher should follow." : "Πόσες ανακατευθύνσεις θα μπορεί να ακολουθεί η υπηρεσία ροών.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Μέγιστος χρόνος σε δευτερόλεπτα, αναμονής φόρτωσης μιας ροής RSS ή Atom; εάν χρειαστεί περισσότερο χρόνο η ενημέρωση θα ματαιωθεί.",
    "Interval in seconds in which the feeds will be updated." : "Διάστημα σε δευτερόλεπτα στο οποίο θα ενημερωθούν τα feeds.",
    "Move" : "Μετακίνηση",
    "Share" : "Διαμοιρασμός",
    "Share with" : "Διαμοιρασμός με",
    "Default" : "Προεπιλογή",
    "Vertical" : "Κάθετα",
    "Off" : "Απενεργοποιημένο",
    "Mark read" : "Σημείωση ως ανεγνωσμένου",
    "All articles" : "Όλα τα άρθρα",
    "Starred" : "Με αστέρι",
    "Explore" : "Εξερεύνηση",
    "Settings" : "Ρυθμίσεις",
    "Documentation" : "Τεκμηρίωση",
    "Keyboard shortcuts" : "Συντομεύσεις πλητρολογίου",
    "Disable mark read through scrolling" : "Απενεργοποίηση σημείωσης ως διαβασμένων κατά τη κύλιση",
    "Show all articles" : "Εμφάνιση όλων των άρθρων",
    "Reverse ordering (oldest on top)" : "Ανεστραμμένη ταξινόμηση (παλαιότερα στην κορυφή)",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Rename Feed" : "Μετονομασία Ροής",
    "Unpin from top" : "Ξεκαρφίτσωμα από την κορυφή",
    "Pin to top" : "Καρφίτσωμα στην κορυφή",
    "Newest first" : "Νεότερο πρώτα",
    "Oldest first" : "Παλαιότερο πρώτα",
    "Default order" : "Προεπιλεγμένη σειρά",
    "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
    "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
    "Previous" : "Προηγούμενο",
    "Next" : "Επόμενο",
    "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
    "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
    "Close details" : "Κλείσιμο λεπτομερειών",
    "shared by" : "σε κοινή χρήση από",
    "by" : "από",
    "Play audio" : "Αναπαραγωγή ήχου",
    "Download audio" : "Λήψη ήχου",
    "Download video" : "Κατεβάστε το βίντεο",
    "Open website" : "Άνοιγμα ιστοσελίδας",
    "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
    "Toggle keep current article unread" : "Εναλλαγή διατήρισης τρέχοντος άρθρου ως μη αναγνωσμένου",
    "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
    "Please wait" : "Παρακαλούμε περιμένετε",
    "Last update" : "Τελευταία ενημέρωση",
    "Title" : "Τίτλος",
    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
    "Action" : "Ενέργεια",
    "Jump to next article" : "Επόμενο άρθρο",
    "Jump to previous article" : "Προηγούμενο άρθρο",
    "right" : "δεξιά",
    "left" : "αριστερά",
    "Star article and jump to next one" : "Επισήμανση άρθρου και μετακίνηση στο επόμενο",
    "Open article in new tab" : "Άνοιγμα άρθρου σε νέα καρτέλα",
    "Refresh" : "Ανανέωση ",
    "Load next feed" : "Φόρτωση επόμενης ροής",
    "Load previous feed" : "Φόρτωση προηγούμενης ροής",
    "Load previous folder" : "Φόρτωση προηγούμενου φακέλου",
    "Load next folder" : "Φόρτωση επόμενου φακέλου",
    "Scroll to active navigation entry" : "Κύλιση στην ενεργή είσοδο πλοήγησης ",
    "Shift" : "Shift",
    "Subscribe to" : "Εγγραφείτε στο",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
    "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα"
},
"nplurals=2; plural=(n != 1);");
